@@ -27,7 +27,7 @@ saslog <- function (options) {
   } else { # backwards compatability
       cmd = options$engine.path
   }
-  out = if (options$eval) {
+  out <- if (options$eval) {
     message("running: ", cmd, " ", code)
     tryCatch(system2(cmd, code, stdout = TRUE, stderr = TRUE,
                      env = options$engine.env), error = function(e) {
@@ -35,31 +35,32 @@ saslog <- function (options) {
                          stop(e)
                        paste("Error in running command", cmd)
                      })
-  }
-  else ""
+  } else ""
   if (!options$error && !is.null(attr(out, "status")))
     stop(paste(out, collapse = "\n"))
   if (is.null(options$encoding))
       enc <- "latin1" else enc <- options$encoding
   if (options$eval && file.exists(listf))
-    out.listing = c(iconv(readLines(listf), from=enc, to="UTF-8"), out) else out.listing=""
+    out.listing <- c(iconv(readLines(listf), from=enc, to="UTF-8"), out) else out.listing=""
   if (options$eval && file.exists(logf))
-    out.log = c(iconv(readLines(logf), from=enc, to="UTF-8"), out)
-  sasinit <- grep("NOTE: SAS initialization", out.log)
-  if (length(sasinit > 0)) {
-      out.log <- out.log[-(1:sasinit+2)]           # trim log header
-  }
-  autoexec <- grep("NOTE: AUTOEXEC processing completed.", out.log)
-  if (length(autoexec > 0)) {
-      out.log <- out.log[-(1:autoexec+1)]           # trim log header
-  }
-  formdelim <- grep("FORMDLIM", out.log)
-  if (length(formdelim > 0)) {
-      out.log <- out.log[-(1:formdelim)]           # trim log header
-  }
-  sasinstitute <- grep("NOTE: SAS Institute Inc.", out.log)
-  if (length(sasinstitute > 0)) {
-      out.log <- try(out.log[1:(sasinstitute-2)], silent=TRUE) # trim log tail
+    out.log <- c(iconv(readLines(logf), from=enc, to="UTF-8"), out) else out.log <- ""
+  if (options$eval && length(out.log > 0)) {
+	sasinit <- grep("NOTE: SAS initialization", out.log)
+	if (length(sasinit > 0)) {
+	 out.log <- out.log[-(1:sasinit+2)]           # trim log header
+	}
+	autoexec <- grep("NOTE: AUTOEXEC processing completed.", out.log)
+	if (length(autoexec > 0)) {
+	 out.log <- out.log[-(1:autoexec+1)]           # trim log header
+	}
+	formdelim <- grep("FORMDLIM", out.log)
+	if (length(formdelim > 0)) {
+	 out.log <- out.log[-(1:formdelim)]           # trim log header
+	}
+	sasinstitute <- grep("NOTE: SAS Institute Inc.", out.log)
+	if (length(sasinstitute > 0)) {
+	 out.log <- try(out.log[1:(sasinstitute-2)], silent=TRUE) # trim log tail
+	}
   }
   
   if (options$engine == "sas" && is.null(attr(out, "status"))) {
